package Intalio::Extensions;

use Exporter qw( import );
our @EXPORT = qw(  SearchConfig SearchExtensions GetExtensionVersion );

use strict;
use FindBin;
use lib "$FindBin::RealBin/../";

use Intalio::Parsers;
use Intalio::SystemUtils;
use Archive::Zip;
use Archive::Zip::MemberRead;
use File::Basename;

sub SearchConfig {
    my @ConfigTemplates = ('db.properties', 'hibernate.cfg.xml', '*.properties', '*.cfg.xml', '*.xml');

    my $ZimbraPath = shift;
    my $ExtensionName = shift;

    my $Debug = shift || 0;

    my $Params = {};

    for my $template (@ConfigTemplates) {
        print "Use patern: $template\n" if $Debug;
        my @Config_files = Intalio::SystemUtils::GetFileList(File::Spec->catdir($ZimbraPath, 'lib/ext', $ExtensionName), $template);
       
        if ( @Config_files ) {
            for my $config_file (@Config_files) {
                print "Looking in " . basename($config_file) . "\n" if $Debug;
                $Params = Intalio::Parsers::ParseConfig($config_file);

                if ( ref($Params) eq 'HASH' ) {
                    print "Found!\n" if $Debug;
                    return $Params;
                } else {
                    print "Not found\n" if $Debug;
                }
            }

        } else {
            print "Not found\n" if $Debug;
        }
    }

    return 0;
}


sub SearchExtensions {
    my $ZimbraPath = shift;
    my $ExtensionName = shift || ''; #Get Specified exitension
    my @Result;

    my @Temp_dirs = Intalio::SystemUtils::GetFileList(File::Spec->catdir($ZimbraPath, 'lib/ext'), $ExtensionName );

    for my $dir (@Temp_dirs) {
        push @Result, basename($dir) if -d $dir;
    }
    
    return sort @Result;

}


sub GetExtensionVersion {
    my $ZimbraPath = shift;
    my $ExtensionName = shift;

    my @Ext = Intalio::SystemUtils::GetFileList( File::Spec->catdir($ZimbraPath, 'lib/ext', $ExtensionName), '*.jar' );
    
    #Maybe it's front-end extension?
    if (! @Ext ) {  
        $ExtensionName =~ s/([A-Z]{1,2})/_${1}/g;
        $ExtensionName = substr((lc $ExtensionName), 1);   #Change to floor separated name
        
        return '' if index(`zmzimletctl listZimlets`, "$ExtensionName\n") == -1;    #Zimlet is instalend on system?
    

        if (`zmzimletctl info $ExtensionName` =~ /Version:\s+(.*)/i) {
            return $1;
        }

    } else {
        my $JarPath = $Ext[0];

        my $handle = Archive::Zip->new($JarPath)->memberNamed('META-INF/MANIFEST.MF')->readFileHandle;
        while (defined(my $line = $handle->getline)) { # even $_ doesn't work!! what a piece of camel dung
            return $1 if $line =~ /ZI-Version:\s+(.+)\s+/i #If found verion in manifest file
        }
    }

    return "";


}