#Intalio::Utils - Intalio utils
#Copyright (C) 2019 by Драпевски Intalio, Release 1.00

package Intalio::Parsers;

use Exporter qw( import );
our @EXPORT = qw(ReadConfigFile ParseProperties ParseHibernate );

use strict;



sub ReadConfigFile {
    my $ConfigPath = shift;
    local $/;

    open(my $fh, "<:encoding(UTF-8)", $ConfigPath ) or die("Can't open file" . $ConfigPath . " : $!\n");
    my $Content = scalar <$fh>;
    close($fh);

    return $Content;
}



sub ParseProperties {
    my $Result = shift;
    my $ConfigPath = shift;

    my $PropertiesContent = ReadConfigFile( $ConfigPath );

    if ( $PropertiesContent =~ m{db_connect_string=jdbc:mariadb://(.+?):(\d+)/(.+?)\?user=(.+?)&password=(.+)}is ) { 
        $Result->{'Host'} = $1;
        $Result->{'Port'} = int($2);
        $Result->{'DatabaseName'} = $3;
        chomp($Result->{'User'} = $4);
        chomp($Result->{'Password'} = $5);
    }  


}

sub ParseHibernate {
    my $Result = shift;
    my $ConfigPath = shift;

    my $HibernateContent = ReadConfigFile( $ConfigPath );
    
    if ( $HibernateContent =~ m{(<\s*property[^<>]*?name="hibernate\.connection\.url"[^<>]*?>)(.*?)(</\s*property\s*>)}is ) {
        my $ConnectionString = $2;
        if ( m{.+?//(.+?):(\d+)/(.+)}i ) {
            $Result->{'Host'} = $1;
            $Result->{'Port'} = int($2);
            $Result->{'DatabaseName'} = $3; 
        }
    }

    if ( $HibernateContent =~ m{(<\s*property[^<>]*?name="hibernate\.connection\.username"[^<>]*?>)(.*?)(</\s*property\s*>)}is ) { 
        $Result->{'User'} = $2;
    }  
    
    if ( $HibernateContent =~ m{(<\s*property[^<>]*?name="hibernate\.connection\.password"[^<>]*?>)(.*?)(</\s*property\s*>)}is ) {
        $Result->{'Password'} = $2;
    }


}


sub ParseConfig {
    my $ConfigPath = shift;

    my %Result = (
        'DatabaseName' => '',
        'Host' => '',
        'Port' => 0,
        'User' => '',
        'Password' => ''
    );

    ParseHibernate(\%Result, $ConfigPath);

    ParseProperties(\%Result, $ConfigPath) if $Result{'Port'} == 0;

    if ( $Result{'Port'} == 0 ) {
        return 0;
    } else {
        return \%Result;
    }


}


1;